---
title: "The Submarine"
date: "April 2005"
---

"Suits make a corporate comeback," says the [_New York Times_](http://www.nytimes.com/2005/04/14/fashion/thursdaystyles/14peacock.html?ex=1271131200&en=e96f2670387e3636&ei=5090&partner=rssuserland). Why does this sound familiar? Maybe because the suit was also back in [February](http://www.cvbizlink.com/articles/2005/04/07/news/news/doc42406f05edf53293947237.prt), [September 2004](http://www.usatoday.com/money/industries/retail/2004-09-01-suits_x.htm), [June 2004](http://www.cnn.com/2004/BUSINESS/06/23/go.fashion.jones/), [March 2004](http://www.post-gazette.com/pg/04062/279616.stm), [September 2003](http://www.southcoasttoday.com/daily/09-03/09-21-03/c01li238.htm), [November 2002](http://www.businessweek.com/magazine/content/02_46/b3808122.htm), [April 2002](http://www.pittsburghlive.com/x/s_65540.html), and [February 2002](http://news.bbc.co.uk/1/hi/business/1836010.stm).

Why do the media keep running stories saying suits are back? Because PR firms [tell](http://www.maximumexposurepr.com/middleMAA.html) them to. One of the most surprising things I discovered during my brief business career was the existence of the PR industry, lurking like a huge, quiet submarine beneath the news. Of the stories you read in traditional media that aren't about politics, crimes, or disasters, more than half probably come from PR firms.

I know because I spent years hunting such "press hits." Our startup spent its entire marketing budget on PR: at a time when we were assembling our own computers to save money, we were paying a PR firm $16,000 a month. And they were worth it. PR is the news equivalent of search engine optimization; instead of buying ads, which readers ignore, you get yourself inserted directly into the stories. \[[1](#f1n)\]

[Our PR firm](http://schwartz-pr.com/client_coverage.php) was one of the best in the business. In 18 months, they got press hits in over 60 different publications. And we weren't the only ones they did great things for. In 1997 I got a call from another startup founder considering hiring them to promote his company. I told him they were PR gods, worth every penny of their outrageous fees. But I remember thinking his company's name was odd. Why call an auction site "eBay"?

**Symbiosis**

PR is not dishonest. Not quite. In fact, the reason the best PR firms are so effective is precisely that they aren't dishonest. They give reporters genuinely valuable information. A good PR firm won't bug reporters just because the client tells them to; they've worked hard to build their credibility with reporters, and they don't want to destroy it by feeding them mere propaganda.

If anyone is dishonest, it's the reporters. The main reason PR firms exist is that reporters are lazy. Or, to put it more nicely, overworked. Really they ought to be out there digging up stories for themselves. But it's so tempting to sit in their offices and let PR firms bring the stories to them. After all, they know good PR firms won't lie to them.

A good flatterer doesn't lie, but tells his victim selective truths (what a nice color your eyes are). Good PR firms use the same strategy: they give reporters stories that are true, but whose truth favors their clients.

For example, our PR firm often pitched stories about how the Web let small merchants compete with big ones. This was perfectly true. But the reason reporters ended up writing stories about this particular truth, rather than some other one, was that small merchants were our target market, and we were paying the piper.

Different publications vary greatly in their reliance on PR firms. At the bottom of the heap are the trade press, who make most of their money from advertising and would give the magazines away for free if advertisers would let them. \[[2](#f2n)\] The average trade publication is a bunch of ads, glued together by just enough articles to make it look like a magazine. They're so desperate for "content" that some will print your press releases almost verbatim, if you take the trouble to write them to read like articles.

At the other extreme are publications like the _New York Times_ and the _Wall Street Journal_. Their reporters do go out and find their own stories, at least some of the time. They'll listen to PR firms, but briefly and skeptically. We managed to get press hits in almost every publication we wanted, but we never managed to crack the print edition of the _Times_. \[[3](#f3n)\]

The weak point of the top reporters is not laziness, but vanity. You don't pitch stories to them. You have to approach them as if you were a specimen under their all-seeing microscope, and make it seem as if the story you want them to run is something they thought of themselves.

Our greatest PR coup was a two-part one. We estimated, based on some fairly informal math, that there were about 5000 stores on the Web. We got one paper to print this number, which seemed neutral enough. But once this "fact" was out there in print, we could quote it to other publications, and claim that with 1000 users we had 20% of the online store market.

This was roughly true. We really did have the biggest share of the online store market, and 5000 was our best guess at its size. But the way the story appeared in the press sounded a lot more definite.

Reporters like definitive statements. For example, many of the stories about Jeremy Jaynes's conviction say that he was one of the 10 worst spammers. This "fact" originated in Spamhaus's ROKSO list, which I think even Spamhaus would admit is a rough guess at the top spammers. The first stories about Jaynes cited this source, but now it's simply repeated as if it were part of the indictment. \[[4](#f4n)\]

All you can say with certainty about Jaynes is that he was a fairly big spammer. But reporters don't want to print vague stuff like "fairly big." They want statements with punch, like "top ten." And PR firms give them what they want. Wearing suits, we're told, will make us [3.6 percent](http://sanfrancisco.bizjournals.com/sanfrancisco/stories/2002/02/25/story5.html?t=printable) more productive.

**Buzz**

Where the work of PR firms really does get deliberately misleading is in the generation of "buzz." They usually feed the same story to several different publications at once. And when readers see similar stories in multiple places, they think there is some important trend afoot. Which is exactly what they're supposed to think.

When Windows 95 was launched, people waited outside stores at midnight to buy the first copies. None of them would have been there without PR firms, who generated such a buzz in the news media that it became self-reinforcing, like a nuclear chain reaction.

I doubt PR firms realize it yet, but the Web makes it possible to track them at work. If you search for the obvious phrases, you turn up several efforts over the years to place stories about the return of the suit. For example, the Reuters article that got picked up by [USA Today](http://www.usatoday.com/money/industries/retail/2004-09-01-suits_x.htm) in September 2004. "The suit is back," it begins.

Trend articles like this are almost always the work of PR firms. Once you know how to read them, it's straightforward to figure out who the client is. With trend stories, PR firms usually line up one or more "experts" to talk about the industry generally. In this case we get three: the NPD Group, the creative director of GQ, and a research director at Smith Barney. \[[5](#f5n)\] When you get to the end of the experts, look for the client. And bingo, there it is: The Men's Wearhouse.

Not surprising, considering The Men's Wearhouse was at that moment running ads saying "The Suit is Back." Talk about a successful press hit-- a wire service article whose first sentence is your own ad copy.

The secret to finding other press hits from a given pitch is to realize that they all started from the same document back at the PR firm. Search for a few key phrases and the names of the clients and the experts, and you'll turn up other variants of this story.

[Casual fridays are out and dress codes are in](http://bostonworks.boston.com/globe/articles/091904_suit.html) writes Diane E. Lewis in _The Boston Globe_. In a remarkable coincidence, Ms. Lewis's industry contacts also include the creative director of GQ.

[Ripped jeans and T-shirts are out,](http://www.usnews.com/usnews/biztech/articles/041108/8eedress.htm) writes Mary Kathleen Flynn in _US News & World Report_. And _she too_ knows the creative director of GQ.

[Men's suits are back](http://www.sexbuzz.com/style/9,0004,00.shtml) writes Nicole Ford in Sexbuzz.Com ("the ultimate men's entertainment magazine").

[Dressing down loses appeal as men suit up at the office](http://www.detnews.com/2004/careers/0405/28/b01-149207.htm) writes Tenisha Mercer of _The Detroit News_.

Now that so many news articles are online, I suspect you could find a similar pattern for most trend stories placed by PR firms. I propose we call this new sport "PR diving," and I'm sure there are far more striking examples out there than this clump of five stories.

**Online**

After spending years chasing them, it's now second nature to me to recognize press hits for what they are. But before we hired a PR firm I had no idea where articles in the mainstream media came from. I could tell a lot of them were crap, but I didn't realize why.

Remember the exercises in critical reading you did in school, where you had to look at a piece of writing and step back and ask whether the author was telling the whole truth? If you really want to be a critical reader, it turns out you have to step back one step further, and ask not just whether the author is telling the truth, but _why he's writing about this subject at all._

Online, the answer tends to be a lot simpler. Most people who publish online write what they write for the simple reason that they want to. You can't see the fingerprints of PR firms all over the articles, as you can in so many print publications-- which is one of the reasons, though they may not consciously realize it, that readers trust bloggers more than _Business Week_.

I was talking recently to a friend who works for a big newspaper. He thought the print media were in serious trouble, and that they were still mostly in denial about it. "They think the decline is cyclic," he said. "Actually it's structural."

In other words, the readers are leaving, and they're not coming back.

Why? I think the main reason is that the writing online is more honest. Imagine how incongruous the _New York Times_ article about suits would sound if you read it in a blog:

> The urge to look corporate-- sleek, commanding, prudent, yet with just a touch of hubris on your well-cut sleeve-- is an unexpected development in a time of business disgrace.

The problem with this article is not just that it originated in a PR firm. The whole tone is bogus. This is the tone of someone writing down to their audience.

Whatever its flaws, the writing you find online is authentic. It's not mystery meat cooked up out of scraps of pitch letters and press releases, and pressed into molds of zippy journalese. It's people writing what they think.

I didn't realize, till there was an alternative, just how artificial most of the writing in the mainstream media was. I'm not saying I used to believe what I read in _Time_ and _Newsweek_. Since high school, at least, I've thought of magazines like that more as guides to what ordinary people were being [told](say.html) to think than as sources of information. But I didn't realize till the last few years that writing for publication didn't have to mean writing that way. I didn't realize you could write as candidly and informally as you would if you were writing to a friend.

Readers aren't the only ones who've noticed the change. The PR industry has too. A hilarious [article](http://www.prsa.org/_Publications/magazines/0802news1.asp) on the site of the PR Society of America gets to the heart of the matter:

> Bloggers are sensitive about becoming mouthpieces for other organizations and companies, which is the reason they began blogging in the first place.

PR people fear bloggers for the same reason readers like them. And that means there may be a struggle ahead. As this new kind of writing draws readers away from traditional media, we should be prepared for whatever PR mutates into to compensate. When I think how hard PR firms work to score press hits in the traditional media, I can't imagine they'll work any less hard to feed stories to bloggers, if they can figure out how.

**Notes**

\[1\] PR has at least one beneficial feature: it favors small companies. If PR didn't work, the only alternative would be to advertise, and only big companies can afford that.

\[2\] Advertisers pay less for ads in free publications, because they assume readers ignore something they get for free. This is why so many trade publications nominally have a cover price and yet give away free subscriptions with such abandon.

\[3\] Different sections of the _Times_ vary so much in their standards that they're practically different papers. Whoever fed the style section reporter this story about suits coming back would have been sent packing by the regular news reporters.

\[4\] The most striking example I know of this type is the "fact" that the Internet worm of 1988 infected 6000 computers. I was there when it was cooked up, and this was the recipe: someone guessed that there were about 60,000 computers attached to the Internet, and that the worm might have infected ten percent of them.

Actually no one knows how many computers the worm infected, because the remedy was to reboot them, and this destroyed all traces. But people like numbers. And so this one is now [replicated](http://www.google.com/search?q=internet+worm+1988+6000) all over the Internet, like a little worm of its own.

\[5\] Not all were necessarily supplied by the PR firm. Reporters sometimes call a few additional sources on their own, like someone adding a few fresh vegetables to a can of soup.

**Thanks** to Ingrid Basset, Trevor Blackwell, Sarah Harlin, Jessica Livingston, Jackie McDonough, Robert Morris, and Aaron Swartz (who also found the PRSA article) for reading drafts of this.

**Correction:** Earlier versions used a recent _Business Week_ article mentioning del.icio.us as an example of a press hit, but Joshua Schachter tells me it was spontaneous.

[The Web is a Writing Environment](http://davenet.scripting.com/2001/04/17/theWebIsAWritingEnvironment)

[A Sell-Out's Tale](http://zpedia.org/A_Sell-Out%27s_Tale)

[How to Pitch Bloggers](http://technoflak.blogspot.com/2005/01/how-to-pitch-bloggers_30.html)

[Blogging for Milk](http://slate.msn.com/id/2081419/)

[7 Habits of Highly Effective Blog PR](http://fusionbrand.blogs.com/fusionbrand/2005/02/nbsp_nbspnbsp_n.html)

[PR People Need To Learn To Deal With New Gatekeepers](http://customers.mediamap.com/articles_5_q2.asp)

[Marqui Blogosphere Program](http://www.marqui.com/Paybloggers/)

[PR Watch](http://www.prwatch.org/)

[Real Men Exfoliate](http://www.boston.com/business/articles/2005/04/19/real_men_exfoliate/)

[How the News is Made](http://www.boingboing.net/fakenews.html)

[January 2006: The suit is back yet again](http://www.businessweek.com/bwdaily/dnflash/jan2006/nf20060120_5808_db035.htm)

[The Decline of the Tie](http://www.guardian.co.uk/commentisfree/story/0,,1864095,00.html)

If you liked this, you may also like [**_Hackers & Painters_**](hackpaint.html).